@@ -3,6 +3,8 @@
 import yaml
 import time
 import os
+import stack.util as util
+from .decorators import ignore
 
 path = 'stack.yaml'
 
@@ -11,6 +13,7 @@ def exist() -> bool:
     return os.path.exists(path)
 
 
+@ignore
 def load() -> dict:
     with open(path, 'r+') as f:
         return yaml.load(''.join(f.readlines()))
@@ -28,3 +31,14 @@ def write(data: dict) -> None:
 
 def has_venv():
     return exist() and os.path.exists('.env')
+
+
+def get_prefix() -> str:
+    '''
+    Find out wich python should be call
+    '''
+    if util.is_venv():
+        return os.environ['VIRTUAL_ENV'] + '/bin/'
+    if has_venv():
+        return '.env/bin/'
+    return ''
