@@ -8,10 +8,17 @@ import stack.util as util
 from stack.decorators import as_command
 import sysconfig
 import traceback
+from fabric.api import local
+
+
+__all__ = ['new', 'upgrade', 'clear', 'set_python', 'init',
+           'setup', 'install', 'uninstall', 'fab', 'test',
+           'coverage', 'run', 'python', 'repl', 'pip', 'doc',
+           'serve', 'pep8_hook']
 
 config_file_exist = config.exist()
 current_path = os.path.dirname(os.path.abspath(__file__))
-prefix = '.env/bin/' if (not util.is_venv()) and config.has_venv() else ''
+prefix = config.get_prefix()
 
 
 def ignore(fn: Callable, value):
@@ -23,7 +30,7 @@ def ignore(fn: Callable, value):
 
 
 @as_command
-def new(args):
+def new(args) -> None:
     '''
     Initalize a new project based on template
     @argument project, metavar=PROJECT, help=your project name
@@ -36,7 +43,7 @@ def new(args):
 
 
 @as_command
-def upgrade(args):
+def upgrade(args) -> None:
     '''
     Upgrade Stack
     '''
@@ -44,7 +51,7 @@ def upgrade(args):
 
 
 @as_command
-def clear(args):
+def clear(args) -> None:
     '''
     Remove virtualenv
     '''
@@ -52,7 +59,7 @@ def clear(args):
 
 
 @as_command
-def set_python(args):
+def set_python(args) -> None:
     '''
     Set python version
     @argument --python, metavar=version, help=Version of Python
@@ -61,7 +68,7 @@ def set_python(args):
 
 
 @as_command
-def init(args):
+def init(args) -> None:
     '''
     Initalize a new project envirement
     @argument --python, metavar=PATH, help=Version of Python, default=python3
@@ -75,22 +82,24 @@ def init(args):
 
 
 @as_command
-def setup(args):
+def setup(args) -> None:
     '''
     Install libs from requirements.txt to venv
+    @argument -r, --requirefile, default='requirement.txt', help=sepec requirement file
     '''
+    dependence = map(lambda x: x.split('==')[0], tuple(open('requirements.txt')))
     ignore(os.system, prefix + 'pip install -r ./requirements.txt --process-dependency-links')
     projectname = os.path.split(os.path.dirname(os.path.realpath(__name__)))[-1]
     config.write(dict(project=projectname))
+    config.write(dict(dependence=dependence))
 
 
 @as_command
-def install(args):
+def install(args) -> None:
     '''
     Install libs from pypi or git repos
     @argument lib, metavar=LIB, help=Lib name
     @argument --repo, metavar=repo, help=Install via a git repo
-    @argument --git, metavar=git, help=Decare is a git repo, default=
     '''
     if not args.lib:
         ignore(os.system, prefix + 'pip install -r ./requirements.txt --process-dependency-links')
@@ -98,14 +107,14 @@ def install(args):
     if not git:
         os.system(prefix + 'pip install %s -v --process-dependency-links' % args.lib)
     if git:
-        template = config.load().get('git_path', 'git+{repo}#egg={lib}')
+        template = 'git+{repo}#egg={lib}'
         repo = template.format(**dict(repo=args.repo, lib=args.lib))
-        os.system(prefix + 'pip install -e %s --process-dependency-links' % repo)
+        local(prefix + 'pip install -e %s --process-dependency-links' % repo)
     os.system(prefix + 'pip freeze > requirements.txt')
 
 
 @as_command
-def uninstall(args):
+def uninstall(args) -> None:
     '''
     Uninstall libs
     @argument lib, metavar=LIB, help=Lib name
@@ -114,7 +123,7 @@ def uninstall(args):
 
 
 @as_command
-def installed(args):
+def installed(args) -> None:
     '''
     List installed libs
     '''
@@ -126,7 +135,7 @@ def installed(args):
 
 
 @as_command
-def fab(args):
+def fab(args) -> None:
     '''
     drop to Fabric
     '''
@@ -134,7 +143,7 @@ def fab(args):
 
 
 @as_command
-def test(args):
+def test(args) -> None:
     '''
     run unittest
     '''
@@ -142,25 +151,29 @@ def test(args):
 
 
 @as_command
-def coverage(args):
+def coverage(args) -> None:
     '''
     Report unittest coverage
     '''
-    project = config.load().get('project')
+    project = os.path.split(os.path.dirname(os.path.realpath(__name__)))[-1]
     return os.system(prefix + 'nosetests -sv --with-coverage --cover-package %s' % project)
 
 
 @as_command
-def run(args):
+def run(args) -> None:
     '''
-    exec file
+    Exec file locally or remote
+    @argument --remote, help=run as remote file
     '''
-    python = config.load().get('python', 'python')
-    return os.system(prefix + '%s %s' % (python, ' '.join(sys.argv[2:])))
+    if args.remote:
+        python = config.load().get('python', 'python')
+        return os.system(prefix + '%s %s' % (python, ' '.join(sys.argv[2:])))
+    else:
+        return os.system('require run %s' % args.remote)
 
 
 @as_command
-def python(args):
+def python(args) -> None:
     '''
     run python
     '''
@@ -169,7 +182,7 @@ def python(args):
 
 
 @as_command
-def repl(args):
+def repl(args) -> None:
     '''
     call ipython as repl
     '''
@@ -177,7 +190,7 @@ def repl(args):
 
 
 @as_command
-def pip(args):
+def pip(args) -> None:
     '''
     call pip
     '''
@@ -185,15 +198,15 @@ def pip(args):
 
 
 @as_command
-def doc(args):
+def doc(args) -> None:
     '''
     audto gen document
     '''
-    return os.system('sphinx-apidoc ./ -o ./docs -F')
+    return os.system('sphinx-apidoc ./ -o ./docs -f -M -F')
 
 
 @as_command
-def serve(args):
+def serve(args) -> None:
     '''
     Serve current dir as as git daemon
     @argument --ip, help=IP addr
@@ -206,50 +219,38 @@ def serve(args):
 
 
 @as_command
-def pep8_hook(args):
+def pep8_hook(args) -> None:
     '''
     Add a pre commit hook to your .git repo
     '''
     os.system('flake8 --install-hook')
 
 
-def router(argv) -> Callable:
+def router(pattern: dict, argv) -> Callable:
     args, unknown = parser.parse_known_args()
     if not len(argv) > 1:
         print(parser.format_help())
         return
-    return {
-        'new': new,
-        'repl': repl,
-        'test': test,
-        'pip': pip,
-        'setup': setup,
-        'python': python,
-        'init': init,
-        'run': run,
-        'clear': clear,
-        'installed': installed,
-        'uninstall': uninstall,
-        'install': install,
-        'pass': uninstall,
-        'serve': serve,
-        'coverage': coverage,
-        'doc': doc,
-        'pep8_hook': pep8_hook,
-        'fab': fab,
-        'set_python': set_python
-    }.get(argv[1], fab)(args)
+    return pattern.get(argv[1], fab)(args)
 
 
 def main():
-    util.info('Using %spython' % prefix or 'System Default ')
-    if len(sys.argv) > 1 and not config.has_venv() and not sys.argv[1] == 'init':
-        util.warn('Command running outside the venv, you may need to run `stack init` first')
+    pattern = {k: v for k, v in globals().items() if k in __all__}
+    util.check_and_update_via_stackfile(pattern)
+    util.info('Using %spython' % (prefix or (util.is_venv() and 'Venv') or 'System Default '))
+    if len(sys.argv) > 1 and not config.has_venv() and not sys.argv[1] == 'init' and not util.is_venv():
+        util.warn('Command running outside the venv, you may need to run `stack init` first, or activite your `venv`')
         util.warn('Using lib path %s' % sysconfig.get_path('platlib'))
+        util.info('Continue? (Y/n)')
+        if input().upper() == 'N':
+            sys.exit()
     try:
-        router(sys.argv)
+        router(pattern, sys.argv)
     except Exception as ex:
-        util.error("Exception <%s>, Traceback: %r" % (str(ex), traceback.format_exc()))
+        util.error("Exception <%s>, Traceback:")
+        map(util.error, (str(ex), traceback.format_exc()))
 
 if __name__ == '__main__':
+    if sys.version_info[:2] < (3, 5) and sys.argv[-1] == 'install':
+        sys.exit('stack requires python 3.5 or higher')
     main()
